@@ -1,14 +1,18 @@
 #![cfg(feature = "full")]
-use std::sync::{
-    atomic::{AtomicI64, AtomicU16, Ordering},
-    Arc,
-};
-
 use async_trait::async_trait;
 use rollo::{
     error::Error,
+    game::GameTime,
     packet::Packet,
-    server::{ListenerSecurity, SocketTools, World, WorldSession, WorldSocketMgr},
+    server::{
+        ListenerSecurity, SocketTools, World, WorldSession, WorldSocketConfiguration,
+        WorldSocketMgr,
+    },
+    AtomicCell,
+};
+use std::sync::{
+    atomic::{AtomicU16, Ordering},
+    Arc,
 };
 use tokio::time::Duration;
 
@@ -16,10 +20,10 @@ use tokio::time::Duration;
 async fn test_game_loop() {
     let world = Box::new(MyWorld {
         counter: AtomicU16::new(0),
-        time: AtomicI64::new(0),
+        game_time: AtomicCell::new(GameTime::new()),
     });
     let world = Box::leak(world);
-    let mut server = WorldSocketMgr::new(world);
+    let mut server = WorldSocketMgr::with_configuration(world, WorldSocketConfiguration::default());
     let t = tokio::spawn(async move {
         let _ = server
             .start_game_loop(Duration::from_millis(100))
@@ -55,16 +59,19 @@ impl WorldSession<MyWorld> for MyWorldSession {
     async fn on_close(_world_session: &Arc<Self>, _world: &'static MyWorld) {}
 }
 
-#[rollo::world_time]
 struct MyWorld {
     counter: AtomicU16,
+    game_time: AtomicCell<GameTime>,
 }
 
 impl World for MyWorld {
     type WorldSessionimplementer = MyWorldSession;
 
-    fn update(&'static self, diff: i64) {
-        assert!(self.time() != 0);
+    fn update(&'static self, diff: i64, game_time: GameTime) {
+        assert_eq!(game_time.timestamp, self.game_time.load().timestamp);
+        assert_eq!(game_time.elapsed, self.game_time.load().elapsed);
+        assert_eq!(game_time.system_time, self.game_time.load().system_time);
+
         let c = self.counter.fetch_add(1, Ordering::Relaxed) + 1;
 
         // First diff is 0
@@ -76,4 +83,8 @@ impl World for MyWorld {
             panic!("test");
         }
     }
+
+    fn game_time(&'static self) -> Option<&'static AtomicCell<GameTime>> {
+        Some(&self.game_time)
+    }
 }
