@@ -1,9 +1,4 @@
 #![cfg(feature = "full")]
-use std::{
-    sync::{atomic::AtomicI64, Arc},
-    time::Duration,
-};
-
 use async_trait::async_trait;
 use bytes::{BufMut, BytesMut};
 use rollo::{
@@ -11,6 +6,7 @@ use rollo::{
     packet::Packet,
     server::{ListenerSecurity, SocketTools, World, WorldSession, WorldSocketMgr},
 };
+use std::{sync::Arc, time::Duration};
 use tokio::{
     io::{AsyncReadExt, AsyncWriteExt},
     net::TcpStream,
@@ -50,9 +46,7 @@ fn packet() -> BytesMut {
 }
 
 async fn setup(port: u32) -> JoinHandle<()> {
-    let world = Box::new(MyWorld {
-        time: AtomicI64::new(0),
-    });
+    let world = Box::new(MyWorld {});
     let world = Box::leak(world);
     let mut server = WorldSocketMgr::new(world);
 
@@ -88,7 +82,6 @@ impl WorldSession<MyWorld> for MyWorldSession {
     async fn on_close(_world_session: &Arc<Self>, _world: &'static MyWorld) {}
 }
 
-#[rollo::world_time]
 struct MyWorld {}
 
 impl World for MyWorld {
